---
title: <span class="badge object-type-scalar"></span> MilligramPerNormalCubicMeter
---
# <span class="badge object-type-scalar"></span> MilligramPerNormalCubicMeter

Concentration: milligram per normal cubic meter (mg/Nm³)

## Definition

```python
# Concentration: milligram per normal cubic meter (mg/Nm³)
MilligramPerNormalCubicMeter: typing.Literal["conmgNm3"] = "conmgNm3"
```
